@@ -57,7 +57,7 @@ esticon.glm <- function (obj, cm, beta0, conf.int = TRUE, level=0.95, joint.test
   }
 }
 
-esticon.mer <- function (obj, cm, beta0, conf.int = TRUE, level=0.95, joint.test=FALSE,...){
+esticon.mer <- esticon.merMod <- function (obj, cm, beta0, conf.int = TRUE, level=0.95, joint.test=FALSE,...){
   if (joint.test==TRUE){
     .wald(obj, cm, beta0)
   } else {
@@ -69,6 +69,9 @@ esticon.mer <- function (obj, cm, beta0, conf.int = TRUE, level=0.95, joint.test
   }
 }
 
+
+
+
 ### ######################################################
 ###
 ### esticon.lme needs better testing at some point
